<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package rallypro
 */

if ( ! function_exists( 'rallypro_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function rallypro_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		/* translators: %s: post date. */
		esc_html_x( 'Posted on %s', 'post date', 'rallypro' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		/* translators: %s: post author. */
		esc_html_x( 'by %s', 'post author', 'rallypro' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'rallypro_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function rallypro_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'rallypro' ) );
		if ( $categories_list && rallypro_categorized_blog() ) {
			/* translators: 1: list of categories. */
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'rallypro' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'rallypro' ) );
		if ( $tags_list ) {
			/* translators: 1: list of tags. */
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'rallypro' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link(
			sprintf(
				wp_kses(
					/* translators: %s: post title */
					__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'rallypro' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			)
		);
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			wp_kses(
				/* translators: %s: Name of current post. Only visible to screen readers */
				__( 'Edit <span class="screen-reader-text">%s</span>', 'rallypro' ),
				array(
					'span' => array(
						'class' => array(),
					),
				)
			),
			get_the_title()
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function rallypro_categorized_blog() {
	$all_the_cool_cats = get_transient( 'rallypro_categories' );
	if ( false === $all_the_cool_cats ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'rallypro_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 || is_preview() ) {
		// This blog has more than 1 category so rallypro_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so rallypro_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in rallypro_categorized_blog.
 */
function rallypro_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'rallypro_categories' );
}
add_action( 'edit_category', 'rallypro_category_transient_flusher' );
add_action( 'save_post',     'rallypro_category_transient_flusher' );


if ( ! function_exists( 'rallypro_content_layout' ) ) :
    /**
     * Theme Content Layout
     */
    function rallypro_content_layout(){

        $layout = get_theme_mod( 'layout_options', 'right-sidebar' );

        if($layout == 'right-sidebar'){
            return 'col-md-8 col-sm-8 col-lg-8 col-xs-12';
        }
        elseif($layout == 'left-sidebar'){
            return 'col-md-8 col-sm-8 col-lg-8 col-md-push-4 col-sm-push-4 col-lg-push-4 col-xs-12';
        }
        else{
            return 'col-md-12 col-sm-12 col-lg-12';
        }

    }
endif;

if ( ! function_exists( 'rallypro_sidebar_layout' ) ) :
    /**
     * Theme Sidebar Layout
     */
    function rallypro_sidebar_layout(){

        $layout = get_theme_mod( 'layout_options', 'right-sidebar' );

        if($layout == 'right-sidebar'){
            return 'col-md-4 col-sm-4  col-lg-4 col-xs-12';
        }
        elseif($layout == 'left-sidebar'){
            return 'col-md-4 col-sm-4  col-lg-4 col-md-pull-8  col-sm-pull-8 col-lg-pull-8 col-xs-12';
        }
        else{
            return 'hidden-sm hidden-md hidden-lg hidden-xs';
        }

    }
endif;

if ( ! function_exists( 'rallypro_animation' ) ) :
    /**
     * Thumbnail animation effect change with layout
     */
    function rallypro_animation(){

        $layout = get_theme_mod( 'layout_options', 'right-sidebar' );

        if($layout == 'right-sidebar'){
            return 'slideInLeft';
        }
        else{
            return 'slideInRight';
        }

    }
endif;